function w = BernsteinWeights(d, j)
%
% MathLab set of functions for B-spline wavelets
% From: E.J. Stollnitz, T.D. DeRose, D.H. Salesin. 
%       Computer Graphics. Theory and Applications.
%       Morgan Kaufmann Publishers, Inc., San Francisco, California, 1996.
%
% Function: w = BernsteinWeights(d, j)
% Purpose:  returns a matrix of B-spline scaling
%           function weights for Bernstein polynomials 
%           of degree d, level j.
%
w = eye(2 ^ j + d);
if d == 0
   return;
end;
u = Knots(d, j);
g = Greville(d, u);
for i = 1 : 2 ^ j - 1
   for r = 1 : d
      [u, g, w] = InsertKnot(d, u, g, w, i / 2 ^ j);
   end;
end;
return;
%... BernsteinWeights()
