function P = FindP(d, j)
%
% MathLab set of functions for B-spline wavelets
% From: E.J. Stollnitz, T.D. DeRose, D.H. Salesin. 
%       Computer Graphics. Theory and Applications.
%       Morgan Kaufmann Publishers, Inc., San Francisco, California, 1996.
%
% Function: P = FindP(d, j)
% Purpose:  returns the P matrix for scaling functions of
%           degree d, level j.
% Comments:
%
d = fix(d);
if d < 0
   error('FindP: Must have d >= 0.');
end;
if d == 0
   P = [1; 1];
   for i = 2 : j
      P = [P zeros(size(P)); zeros(size(p)) P];
   end;
else
   u = Knots(d, j - 1);
   g = Greville(d, u);
   P = eye(2^(j - 1) + d);
   for k = 0 : 2 ^ (j - 1) - 1
      [u, g, P] = InsertKnot(d, u, g, P, (2 * k + 1) / 2 ^ j);
   end;
end;
return;
% ... FindP()

     
